[−][src]Module vm_memory::address
Traits to represent an address within an address space.
Two traits are defined to represent an address within an address space:
- AddressValue: stores the raw value of an address. Typically
u32,u64orusizeis used to store the raw value. But pointers, such as*u8, can't be used because they don't implement theAddandSubtraits. - Address: encapsulates an
AddressValueobject and defines methods to access and manipulate it.
Traits
| Address | Trait to represent an address within an address space. |
| AddressValue | Simple helper trait used to store a raw address value. |