WithBitmapSlice

Trait WithBitmapSlice 

pub trait WithBitmapSlice<'a> {
    type S: BitmapSlice;
}
Trait implemented by types that support creating BitmapSlice objects.

Required Associated Types

type S: BitmapSlice

Type of the bitmap slice.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl WithBitmapSlice<'_> for ()

A no-op Bitmap implementation that can be provided for backends that do not actually require the tracking functionality.

Source

type S = ()

Source

impl<'a, B> WithBitmapSlice<'a> for Option<B>
where B: WithBitmapSlice<'a>,

A Bitmap and BitmapSlice implementation for Option<B>.

Source

type S = Option<<B as WithBitmapSlice<'a>>::S>

Implementors

Source

impl<'a> WithBitmapSlice<'a> for AtomicBitmap

Available on crate feature backend-bitmap only.
Source

type S = BaseSlice<&'a AtomicBitmap>