pub trait AtomicAccess:
ByteValued
+ From<<Self::A as AtomicInteger>::V>
+ Into<<Self::A as AtomicInteger>::V> {
type A: AtomicInteger;
}Expand description
A trait used to identify types which can be accessed atomically by proxy.
Required Associated Types
Sourcetype A: AtomicInteger
type A: AtomicInteger
The AtomicInteger that atomic operations on Self are based on.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".