pub struct GuestAddress(pub u64);
Represents a guest physical address (GPA).

Notes:

On ARM64, a 32-bit hypervisor may be used to support a 64-bit guest. For simplicity, u64 is used to store the the raw value no matter if the guest a 32-bit or 64-bit virtual machine.

Tuple Fields

0: u64