pub enum Error {
CannotResolve {
iova_range: IovaRange,
reason: String,
},
Fragmented {
iova_range: IovaRange,
continuous_length: usize,
},
IommuMisconfigured {
reason: String,
},
}Available on crate feature
iommu only.Expand description
Errors associated with IOMMU address translation.
Variants
CannotResolve
Lookup cannot be resolved.
Fields
Fragmented
Wanted to translate an IOVA range into a single slice, but the range is fragmented.
Fields
IommuMisconfigured
IOMMU is not configured correctly, and so cannot translate addresses.