Module mmap

Module mmap 

Available on crate feature backend-mmap only.
The default implementation for the GuestMemoryBackend trait.

This implementation is mmap-ing the memory of the guest into the current process.

Re-exports

pub use crate::bitmap::NewBitmap;

Structs

GuestRegionMmap
GuestMemoryRegion implementation that mmaps the guest’s memory region in the current process.
MmapRangetarget_family=unix and xen
MmapRange represents a range of arguments required to create Mmap regions.
MmapRegiontarget_family=unix and xen
Helper structure for working with mmaped memory regions with Xen.
MmapXenFlagstarget_family=unix and xen
Flags for the Xen mmap message.

Enums

FromRangesError
Errors that can happen during GuestMemoryMmap::from_ranges and related functions.
MmapRegionErrortarget_family=unix and xen
Error conditions that may arise when creating a new MmapRegion object.

Type Aliases

GuestMemoryMmap
GuestMemoryBackend implementation that mmaps the guest’s memory in the current process.