pub enum Error {
OutOfBounds {
addr: usize,
},
Overflow {
base: usize,
offset: usize,
},
TooBig {
nelements: usize,
size: usize,
},
Misaligned {
addr: usize,
alignment: usize,
},
IOError(Error),
PartialBuffer {
expected: usize,
completed: usize,
},
}Expand description
VolatileMemory related errors.
Variants
OutOfBounds
addr is out of bounds of the volatile memory slice.
Overflow
Taking a slice at base with offset would overflow usize.
TooBig
Taking a slice whose size overflows usize.
Misaligned
Trying to obtain a misaligned reference.
IOError(Error)
Writing to memory failed
PartialBuffer
Incomplete read or write